# OPS02-BP01: Resources have identified owners

## Description

Mỗi resource/workload cần có owner rõ ràng.

## Implementation Guidance

- Tag all cloud resources with owner information
- Maintain resource inventory with ownership data
- Define ownership transfer processes
- Regular ownership audits
- Clear escalation paths for orphaned resources

## Risk Level

High - Unowned resources lead to security and cost issues.
